@@ -1,5 +1,6 @@
 import requests
-from browserbook.tools.canOpener import Open
+from BrowserBook.browserbook.tools.canOpener import Open
+from BrowserBook.browserbook.tools.URIreader import read
 from bs4 import BeautifulSoup
 import shutil
 from uuid import uuid4
@@ -24,6 +25,8 @@ class SessionObject:
     self.baseParams = {}
     self.url = ''
     self.localize = False
+    self.log = True
+    self.URI = False
   def get(self, url):
     self.url = url[:url.rfind('?')]
     if not 'www.' in self.url:
@@ -55,27 +58,51 @@ class SessionObject:
     return output
       
   def getAllSaveAll(self, reqlist):
+    core = self.url[0:len(self.url)-1]
     host = self.url[0:len(self.url)-1]
+    host = host.split('/')
+    
+    host = '/'.join(host[0:3])+'/'
     headers = {'User-Agent': 'Mozilla/5.0 (Macintosh; Intel Mac OS X 10_10_1) AppleWebKit/537.36 (KHTML, like Gecko) Chrome/39.0.2171.95 Safari/537.36', 'Referer':host}
     reqlist.insert(0, '/index.html')
     
     
-    print(f'From {host} getting data.')
+    print(f'From {core} getting data.')
     for req in reqlist:
       if not req.startswith(host) and not req.startswith('/'):
         if self.localize == True:
-          print(f'[GET]: {req}')
-          r = requests.get(req, headers=headers)
-          c = r.content
-          path = req.replace('https://','')
-          path=path[:path.rfind('?')]
-          path = path.replace('http://','')
-          path = path.split('/')[3:len(req)-1]
-          path = '/'.join(path)
-          file =Open(f'{os.getcwd()}/{self.name}/sessions/{self.id}/externalSRC/{path}')
-          file.write(c)
-          file.close
+          if self.log:
+            print(f'[GET]: {req}')
+          if req.startswith('data:image'):
+            if not self.URI:
+              warnings.warn(f'Encounterd a Data url source.', SyntaxWarning)
+            else:
+              red = read(req)
+              f = Open(f'{os.getcwd()}/{self.name}/sessions/{self.id}/externalSRC/URI/{str(uuid4())[:8]}.{red["filetype"]}') 
+              
+              f.write(red['bytes'])
+            
+          else:
+            r = requests.get(req, headers=headers)
+            c = r.content
+            if req.rfind('?') > 0:
+              req=req[:req.rfind('?')]
+            else:
+            
+              req = req
+          
+            path = req
+            path = path.replace('https://','')
+          
+            path = path.replace('http://','')
+            path = path.split('/')[1:]
+            path = '/'.join(path)
+            file =Open(f'{os.getcwd()}/{self.name}/sessions/{self.id}/externalSRC/{path}')
+            file.write(c)
+            file.close
       else:
+        if req.startswith('data:'):
+            warnings.warn(f'Unable to read source url: {req}', SyntaxWarning)
         req = req.replace(host, '')
         if req.rfind('?') > 0:
           params = req[req.rfind('?'):]
@@ -84,7 +111,8 @@ class SessionObject:
         else:
           params = {}
           req = req
-          print(f'[GET]: {host+req}')
+          if self.log:
+            print(f'[GET]: {host+req}')
         
       
         req = req.replace('https://','')
@@ -92,7 +120,7 @@ class SessionObject:
         
       
         if req == '/index.html':
-          r = requests.get(host+'/', headers=headers, params=params)
+          r = requests.get(core+'/', headers=headers, params=params)
         else:
           r = requests.get(host+req, headers=headers, params=params)
         c = r.content
@@ -159,11 +187,17 @@ class SessionObject:
 class brbook():
   def __init__(self, name):
     self.name = name
+    
     if not os.path.isdir(f'{os.getcwd()}/{name}'):
+      
       os.mkdir(name)
       os.mkdir(f'{name}/sessions')
+    else:
+      shutil.rmtree(f'{os.getcwd()}/{self.name}/sessions')
+      os.mkdir(f'{name}/sessions')
   def sessionStart(self):
     session = uuid4()
+    
     if os.path.isdir(f'{os.getcwd()}/{self.name}/sessions/{session}'):
       raise OSError('Duplicate session, try again')
     os.mkdir(f'{self.name}/sessions/{session}')
